@@ -16,21 +16,12 @@
 # under the License.
 from __future__ import annotations
 
+import os
 import traceback
 from contextlib import ExitStack
 from typing import TYPE_CHECKING
 
 import yaml
-
-from airflow.providers.openlineage import __version__ as OPENLINEAGE_PROVIDER_VERSION, conf
-from airflow.providers.openlineage.utils.utils import (
-    OpenLineageRedactor,
-    get_airflow_debug_facet,
-    get_airflow_state_run_facet,
-    get_processing_engine_facet,
-)
-from airflow.stats import Stats
-from airflow.utils.log.logging_mixin import LoggingMixin
 from openlineage.client import OpenLineageClient, set_producer
 from openlineage.client.event_v2 import Job, Run, RunEvent, RunState
 from openlineage.client.facet_v2 import (
@@ -41,11 +32,21 @@ from openlineage.client.facet_v2 import (
     job_type_job,
     nominal_time_run,
     ownership_job,
-    parent_run,
     source_code_location_job,
 )
 from openlineage.client.uuid import generate_static_uuid
 
+from airflow.configuration import conf as airflow_conf
+from airflow.providers.openlineage import __version__ as OPENLINEAGE_PROVIDER_VERSION, conf
+from airflow.providers.openlineage.utils.utils import (
+    OpenLineageRedactor,
+    get_airflow_debug_facet,
+    get_airflow_state_run_facet,
+    get_processing_engine_facet,
+)
+from airflow.stats import Stats
+from airflow.utils.log.logging_mixin import LoggingMixin
+
 if TYPE_CHECKING:
     from datetime import datetime
 
@@ -81,11 +82,16 @@ class OpenLineageAdapter(LoggingMixin):
 
     def get_or_create_openlineage_client(self) -> OpenLineageClient:
         if not self._client:
+            # If not already set explicitly - propagate airflow logging level to OpenLineage client
+            airflow_core_log_level = airflow_conf.get("logging", "logging_level", fallback="INFO")
+            if not os.getenv("OPENLINEAGE_CLIENT_LOGGING") and airflow_core_log_level != "INFO":
+                os.environ["OPENLINEAGE_CLIENT_LOGGING"] = airflow_core_log_level
+
             config = self.get_openlineage_config()
             if config:
                 self.log.debug(
                     "OpenLineage configuration found. Transport type: `%s`",
-                    config.get("type", "no type provided"),
+                    config.get("transport", {}).get("type", "no type provided"),
                 )
                 self._client = OpenLineageClient(config=config)  # type: ignore[call-arg]
             else:
@@ -102,8 +108,7 @@ class OpenLineageAdapter(LoggingMixin):
         if openlineage_config_path:
             config = self._read_yaml_config(openlineage_config_path)
             return config
-        else:
-            self.log.debug("OpenLineage config_path configuration not found.")
+        self.log.debug("OpenLineage config_path configuration not found.")
 
         # Second, try to get transport config
         transport_config = conf.transport()
@@ -159,11 +164,20 @@ class OpenLineageAdapter(LoggingMixin):
                 stack.enter_context(Stats.timer(f"ol.emit.attempts.{event_type}.{transport_type}"))
                 stack.enter_context(Stats.timer("ol.emit.attempts"))
                 self._client.emit(redacted_event)
-                self.log.debug("Successfully emitted OpenLineage event of id %s", event.run.runId)
-        except Exception:
+                self.log.info(
+                    "Successfully emitted OpenLineage `%s` event of id `%s`",
+                    event_type.upper(),
+                    event.run.runId,
+                )
+        except Exception as e:
             Stats.incr("ol.emit.failed")
-            self.log.warning("Failed to emit OpenLineage event of id %s", event.run.runId)
-            self.log.debug("OpenLineage emission failure: %s", exc_info=True)
+            self.log.warning(
+                "Failed to emit OpenLineage `%s` event of id `%s` with the following exception: `%s`",
+                event_type.upper(),
+                event.run.runId,
+                e,
+            )
+            self.log.debug("OpenLineage emission failure details:", exc_info=True)
 
         return redacted_event
 
@@ -173,8 +187,6 @@ class OpenLineageAdapter(LoggingMixin):
         job_name: str,
         job_description: str,
         event_time: str,
-        parent_job_name: str | None,
-        parent_run_id: str | None,
         code_location: str | None,
         nominal_start_time: str | None,
         nominal_end_time: str | None,
@@ -189,9 +201,6 @@ class OpenLineageAdapter(LoggingMixin):
         :param job_name: globally unique identifier of task in dag
         :param job_description: user provided description of job
         :param event_time:
-        :param parent_job_name: the name of the parent job (typically the DAG,
-                but possibly a task group)
-        :param parent_run_id: identifier of job spawning this task
         :param code_location: file path or URL of DAG file
         :param nominal_start_time: scheduled time of dag run
         :param nominal_end_time: following schedule of dag run
@@ -208,9 +217,6 @@ class OpenLineageAdapter(LoggingMixin):
             eventTime=event_time,
             run=self._build_run(
                 run_id=run_id,
-                job_name=job_name,
-                parent_job_name=parent_job_name,
-                parent_run_id=parent_run_id,
                 nominal_start_time=nominal_start_time,
                 nominal_end_time=nominal_end_time,
                 run_facets=run_facets,
@@ -233,8 +239,6 @@ class OpenLineageAdapter(LoggingMixin):
         self,
         run_id: str,
         job_name: str,
-        parent_job_name: str | None,
-        parent_run_id: str | None,
         end_time: str,
         task: OperatorLineage,
         run_facets: dict[str, RunFacet] | None = None,
@@ -244,9 +248,6 @@ class OpenLineageAdapter(LoggingMixin):
 
         :param run_id: globally unique identifier of task in dag run
         :param job_name: globally unique identifier of task between dags
-        :param parent_job_name: the name of the parent job (typically the DAG,
-                but possibly a task group)
-        :param parent_run_id: identifier of job spawning this task
         :param end_time: time of task completion
         :param task: metadata container with information extracted from operator
         :param run_facets: additional run facets
@@ -260,9 +261,6 @@ class OpenLineageAdapter(LoggingMixin):
             eventTime=end_time,
             run=self._build_run(
                 run_id=run_id,
-                job_name=job_name,
-                parent_job_name=parent_job_name,
-                parent_run_id=parent_run_id,
                 run_facets=run_facets,
             ),
             job=self._build_job(job_name, job_type=_JOB_TYPE_TASK, job_facets=task.job_facets),
@@ -276,8 +274,6 @@ class OpenLineageAdapter(LoggingMixin):
         self,
         run_id: str,
         job_name: str,
-        parent_job_name: str | None,
-        parent_run_id: str | None,
         end_time: str,
         task: OperatorLineage,
         error: str | BaseException | None = None,
@@ -288,9 +284,6 @@ class OpenLineageAdapter(LoggingMixin):
 
         :param run_id: globally unique identifier of task in dag run
         :param job_name: globally unique identifier of task between dags
-        :param parent_job_name: the name of the parent job (typically the DAG,
-                but possibly a task group)
-        :param parent_run_id: identifier of job spawning this task
         :param end_time: time of task completion
         :param task: metadata container with information extracted from operator
         :param run_facets: custom run facets
@@ -317,9 +310,6 @@ class OpenLineageAdapter(LoggingMixin):
             eventTime=end_time,
             run=self._build_run(
                 run_id=run_id,
-                job_name=job_name,
-                parent_job_name=parent_job_name,
-                parent_run_id=parent_run_id,
                 run_facets=run_facets,
             ),
             job=self._build_job(job_name, job_type=_JOB_TYPE_TASK, job_facets=task.job_facets),
@@ -357,7 +347,6 @@ class OpenLineageAdapter(LoggingMixin):
                     run_id=self.build_dag_run_id(
                         dag_id=dag_id, logical_date=logical_date, clear_number=clear_number
                     ),
-                    job_name=dag_id,
                     nominal_start_time=nominal_start_time,
                     nominal_end_time=nominal_end_time,
                     run_facets={**run_facets, **get_airflow_debug_facet(), **get_processing_engine_facet()},
@@ -371,7 +360,7 @@ class OpenLineageAdapter(LoggingMixin):
             # Catch all exceptions to prevent ProcessPoolExecutor from silently swallowing them.
             # This ensures that any unexpected exceptions are logged for debugging purposes.
             # This part cannot be wrapped to deduplicate code, otherwise the method cannot be pickled in multiprocessing.
-            self.log.warning("Failed to emit DAG started event: \n %s", traceback.format_exc())
+            self.log.warning("Failed to emit OpenLineage DAG started event: \n %s", traceback.format_exc())
 
     def dag_success(
         self,
@@ -409,7 +398,7 @@ class OpenLineageAdapter(LoggingMixin):
             # Catch all exceptions to prevent ProcessPoolExecutor from silently swallowing them.
             # This ensures that any unexpected exceptions are logged for debugging purposes.
             # This part cannot be wrapped to deduplicate code, otherwise the method cannot be pickled in multiprocessing.
-            self.log.warning("Failed to emit DAG success event: \n %s", traceback.format_exc())
+            self.log.warning("Failed to emit OpenLineage DAG success event: \n %s", traceback.format_exc())
 
     def dag_failed(
         self,
@@ -453,14 +442,11 @@ class OpenLineageAdapter(LoggingMixin):
             # Catch all exceptions to prevent ProcessPoolExecutor from silently swallowing them.
             # This ensures that any unexpected exceptions are logged for debugging purposes.
             # This part cannot be wrapped to deduplicate code, otherwise the method cannot be pickled in multiprocessing.
-            self.log.warning("Failed to emit DAG failed event: \n %s", traceback.format_exc())
+            self.log.warning("Failed to emit OpenLineage DAG failed event: \n %s", traceback.format_exc())
 
     @staticmethod
     def _build_run(
         run_id: str,
-        job_name: str,
-        parent_job_name: str | None = None,
-        parent_run_id: str | None = None,
         nominal_start_time: str | None = None,
         nominal_end_time: str | None = None,
         run_facets: dict[str, RunFacet] | None = None,
@@ -470,13 +456,6 @@ class OpenLineageAdapter(LoggingMixin):
             facets.update(
                 {"nominalTime": nominal_time_run.NominalTimeRunFacet(nominal_start_time, nominal_end_time)}
             )
-        if parent_run_id:
-            parent_run_facet = parent_run.ParentRunFacet(
-                run=parent_run.Run(runId=parent_run_id),
-                job=parent_run.Job(namespace=conf.namespace(), name=parent_job_name or job_name),
-            )
-            facets.update({"parent": parent_run_facet})
-
         if run_facets:
             facets.update(run_facets)
 
