@@ -23,16 +23,16 @@ from datetime import datetime
 from typing import TYPE_CHECKING
 
 import psutil
+from openlineage.client.serde import Serde
 from setproctitle import getproctitle, setproctitle
 
 from airflow import settings
 from airflow.listeners import hookimpl
-from airflow.models import DagRun
+from airflow.models import DagRun, TaskInstance
 from airflow.providers.openlineage import conf
-from airflow.providers.openlineage.extractors import ExtractorManager
+from airflow.providers.openlineage.extractors import ExtractorManager, OperatorLineage
 from airflow.providers.openlineage.plugins.adapter import OpenLineageAdapter, RunState
 from airflow.providers.openlineage.utils.utils import (
-    AIRFLOW_V_2_10_PLUS,
     AIRFLOW_V_3_0_PLUS,
     get_airflow_dag_run_facet,
     get_airflow_debug_facet,
@@ -40,6 +40,7 @@ from airflow.providers.openlineage.utils.utils import (
     get_airflow_mapped_task_facet,
     get_airflow_run_facet,
     get_job_name,
+    get_task_parent_run_facet,
     get_user_provided_run_facets,
     is_operator_disabled,
     is_selective_lineage_enabled,
@@ -50,32 +51,25 @@ from airflow.stats import Stats
 from airflow.utils import timezone
 from airflow.utils.state import TaskInstanceState
 from airflow.utils.timeout import timeout
-from openlineage.client.serde import Serde
 
 if TYPE_CHECKING:
-    from airflow.models import TaskInstance
     from airflow.sdk.execution_time.task_runner import RuntimeTaskInstance
     from airflow.settings import Session
 
 _openlineage_listener: OpenLineageListener | None = None
 
 
-def _get_try_number_success(val):
-    # todo: remove when min airflow version >= 2.10.0
-    if AIRFLOW_V_2_10_PLUS:
-        return val.try_number
-    return val.try_number - 1
-
-
 def _executor_initializer():
     """
-    Initialize worker processes for the executor used for DagRun listener.
+    Initialize processes for the executor used with DAGRun listener's methods (on scheduler).
 
     This function must be picklable, so it cannot be defined as an inner method or local function.
 
     Reconfigures the ORM engine to prevent issues that arise when multiple processes interact with
     the Airflow database.
     """
+    # This initializer is used only on the scheduler
+    # We can configure_orm regardless of the Airflow version, as DB access is always allowed from scheduler.
     settings.configure_orm()
 
 
@@ -104,7 +98,7 @@ class OpenLineageListener:
                 assert task
             dagrun = context["dag_run"]
             dag = context["dag"]
-            start_date = context["start_date"]
+            start_date = task_instance.start_date
             self._on_task_instance_running(task_instance, dag, dagrun, task, start_date)
     else:
 
@@ -199,21 +193,22 @@ class OpenLineageListener:
             operator_name = task.task_type.lower()
 
             with Stats.timer(f"ol.extract.{event_type}.{operator_name}"):
-                task_metadata = self.extractor_manager.extract_metadata(dagrun, task)
+                task_metadata = self.extractor_manager.extract_metadata(
+                    dagrun=dagrun, task=task, task_instance_state=TaskInstanceState.RUNNING
+                )
 
             redacted_event = self.adapter.start_task(
                 run_id=task_uuid,
                 job_name=get_job_name(task),
                 job_description=dag.description,
                 event_time=start_date.isoformat(),
-                parent_job_name=dag.dag_id,
-                parent_run_id=parent_run_id,
                 code_location=None,
                 nominal_start_time=data_interval_start,
                 nominal_end_time=data_interval_end,
                 owners=dag.owner.split(", "),
                 task=task_metadata,
                 run_facets={
+                    **get_task_parent_run_facet(parent_run_id=parent_run_id, parent_job_name=dag.dag_id),
                     **get_user_provided_run_facets(task_instance, TaskInstanceState.RUNNING),
                     **get_airflow_mapped_task_facet(task_instance),
                     **get_airflow_run_facet(dagrun, dag, task_instance, task, task_uuid),
@@ -231,10 +226,18 @@ class OpenLineageListener:
 
         @hookimpl
         def on_task_instance_success(
-            self, previous_state: TaskInstanceState, task_instance: RuntimeTaskInstance
+            self, previous_state: TaskInstanceState, task_instance: RuntimeTaskInstance | TaskInstance
         ) -> None:
             self.log.debug("OpenLineage listener got notification about task instance success")
 
+            if isinstance(task_instance, TaskInstance):
+                self._on_task_instance_manual_state_change(
+                    ti=task_instance,
+                    dagrun=task_instance.dag_run,
+                    ti_state=TaskInstanceState.SUCCESS,
+                )
+                return
+
             context = task_instance.get_template_context()
             task = context["task"]
             if TYPE_CHECKING:
@@ -293,7 +296,7 @@ class OpenLineageListener:
             task_uuid = self.adapter.build_task_instance_run_id(
                 dag_id=dag.dag_id,
                 task_id=task.task_id,
-                try_number=_get_try_number_success(task_instance),
+                try_number=task_instance.try_number,
                 logical_date=date,
                 map_index=task_instance.map_index,
             )
@@ -302,17 +305,19 @@ class OpenLineageListener:
 
             with Stats.timer(f"ol.extract.{event_type}.{operator_name}"):
                 task_metadata = self.extractor_manager.extract_metadata(
-                    dagrun, task, complete=True, task_instance=task_instance
+                    dagrun=dagrun,
+                    task=task,
+                    task_instance_state=TaskInstanceState.SUCCESS,
+                    task_instance=task_instance,
                 )
 
             redacted_event = self.adapter.complete_task(
                 run_id=task_uuid,
                 job_name=get_job_name(task),
-                parent_job_name=dag.dag_id,
-                parent_run_id=parent_run_id,
                 end_time=end_date.isoformat(),
                 task=task_metadata,
                 run_facets={
+                    **get_task_parent_run_facet(parent_run_id=parent_run_id, parent_job_name=dag.dag_id),
                     **get_user_provided_run_facets(task_instance, TaskInstanceState.SUCCESS),
                     **get_airflow_run_facet(dagrun, dag, task_instance, task, task_uuid),
                     **get_airflow_debug_facet(),
@@ -331,10 +336,20 @@ class OpenLineageListener:
         def on_task_instance_failed(
             self,
             previous_state: TaskInstanceState,
-            task_instance: TaskInstance,
+            task_instance: RuntimeTaskInstance | TaskInstance,
             error: None | str | BaseException,
         ) -> None:
             self.log.debug("OpenLineage listener got notification about task instance failure")
+
+            if isinstance(task_instance, TaskInstance):
+                self._on_task_instance_manual_state_change(
+                    ti=task_instance,
+                    dagrun=task_instance.dag_run,
+                    ti_state=TaskInstanceState.FAILED,
+                    error=error,
+                )
+                return
+
             context = task_instance.get_template_context()
             task = context["task"]
             if TYPE_CHECKING:
@@ -342,8 +357,7 @@ class OpenLineageListener:
             dagrun = context["dag_run"]
             dag = context["dag"]
             self._on_task_instance_failed(task_instance, dag, dagrun, task, error)
-
-    elif AIRFLOW_V_2_10_PLUS:
+    else:
 
         @hookimpl
         def on_task_instance_failed(
@@ -358,19 +372,6 @@ class OpenLineageListener:
             if TYPE_CHECKING:
                 assert task
             self._on_task_instance_failed(task_instance, task.dag, task_instance.dag_run, task, error)
-    else:
-
-        @hookimpl
-        def on_task_instance_failed(
-            self,
-            previous_state: TaskInstanceState,
-            task_instance: TaskInstance,
-            session: Session,  # type: ignore[valid-type]
-        ) -> None:
-            task = task_instance.task
-            if TYPE_CHECKING:
-                assert task
-            self._on_task_instance_failed(task_instance, task.dag, task_instance.dag_run, task)
 
     def _on_task_instance_failed(
         self,
@@ -423,18 +424,20 @@ class OpenLineageListener:
 
             with Stats.timer(f"ol.extract.{event_type}.{operator_name}"):
                 task_metadata = self.extractor_manager.extract_metadata(
-                    dagrun, task, complete=True, task_instance=task_instance
+                    dagrun=dagrun,
+                    task=task,
+                    task_instance_state=TaskInstanceState.FAILED,
+                    task_instance=task_instance,
                 )
 
             redacted_event = self.adapter.fail_task(
                 run_id=task_uuid,
                 job_name=get_job_name(task),
-                parent_job_name=dag.dag_id,
-                parent_run_id=parent_run_id,
                 end_time=end_date.isoformat(),
                 task=task_metadata,
                 error=error,
                 run_facets={
+                    **get_task_parent_run_facet(parent_run_id=parent_run_id, parent_job_name=dag.dag_id),
                     **get_user_provided_run_facets(task_instance, TaskInstanceState.FAILED),
                     **get_airflow_run_facet(dagrun, dag, task_instance, task, task_uuid),
                     **get_airflow_debug_facet(),
@@ -447,6 +450,61 @@ class OpenLineageListener:
 
         self._execute(on_failure, "on_failure", use_fork=True)
 
+    def _on_task_instance_manual_state_change(
+        self,
+        ti: TaskInstance,
+        dagrun: DagRun,
+        ti_state: TaskInstanceState,
+        error: None | str | BaseException = None,
+    ) -> None:
+        self.log.debug("`_on_task_instance_manual_state_change` was called with state: `%s`.", ti_state)
+        end_date = timezone.utcnow()
+
+        @print_warning(self.log)
+        def on_state_change():
+            date = dagrun.logical_date or dagrun.run_after
+            parent_run_id = self.adapter.build_dag_run_id(
+                dag_id=dagrun.dag_id,
+                logical_date=date,
+                clear_number=dagrun.clear_number,
+            )
+
+            task_uuid = self.adapter.build_task_instance_run_id(
+                dag_id=dagrun.dag_id,
+                task_id=ti.task_id,
+                try_number=ti.try_number,
+                logical_date=date,
+                map_index=ti.map_index,
+            )
+
+            adapter_kwargs = {
+                "run_id": task_uuid,
+                "job_name": get_job_name(ti),
+                "end_time": end_date.isoformat(),
+                "task": OperatorLineage(),
+                "run_facets": {
+                    **get_task_parent_run_facet(parent_run_id=parent_run_id, parent_job_name=ti.dag_id),
+                    **get_airflow_debug_facet(),
+                },
+            }
+
+            if ti_state == TaskInstanceState.FAILED:
+                event_type = RunState.FAIL.value.lower()
+                redacted_event = self.adapter.fail_task(**adapter_kwargs, error=error)
+            elif ti_state == TaskInstanceState.SUCCESS:
+                event_type = RunState.COMPLETE.value.lower()
+                redacted_event = self.adapter.complete_task(**adapter_kwargs)
+            else:
+                raise ValueError(f"Unsupported ti_state: `{ti_state}`.")
+
+            operator_name = ti.operator.lower()
+            Stats.gauge(
+                f"ol.event.size.{event_type}.{operator_name}",
+                len(Serde.to_json(redacted_event).encode("utf-8")),
+            )
+
+        self._execute(on_state_change, "on_state_change", use_fork=True)
+
     def _execute(self, callable, callable_name: str, use_fork: bool = False):
         if use_fork:
             self._fork_execute(callable, callable_name)
@@ -472,7 +530,9 @@ class OpenLineageListener:
                 process.wait(conf.execution_timeout())
             except psutil.TimeoutExpired:
                 self.log.warning(
-                    "OpenLineage process %s expired. This should not affect process execution.", pid
+                    "OpenLineage process with pid `%s` expired and will be terminated by listener. "
+                    "This has no impact on actual task execution status.",
+                    pid,
                 )
                 self._terminate_with_wait(process)
             except BaseException:
@@ -481,7 +541,8 @@ class OpenLineageListener:
             self.log.debug("Process with pid %s finished - parent", pid)
         else:
             setproctitle(getproctitle() + " - OpenLineage - " + callable_name)
-            configure_orm(disable_connection_pool=True)
+            if not AIRFLOW_V_3_0_PLUS:
+                configure_orm(disable_connection_pool=True)
             self.log.debug("Executing OpenLineage process - %s - pid %s", callable_name, os.getpid())
             callable()
             self.log.debug("Process with current pid finishes after %s", callable_name)
@@ -567,10 +628,7 @@ class OpenLineageListener:
                 self.log.debug("Executor have not started before `on_dag_run_success`")
                 return
 
-            if AIRFLOW_V_2_10_PLUS:
-                task_ids = DagRun._get_partial_task_ids(dag_run.dag)
-            else:
-                task_ids = dag_run.dag.task_ids if dag_run.dag and dag_run.dag.partial else None
+            task_ids = DagRun._get_partial_task_ids(dag_run.dag)
 
             date = dag_run.logical_date
             if AIRFLOW_V_3_0_PLUS and date is None:
@@ -606,10 +664,7 @@ class OpenLineageListener:
                 self.log.debug("Executor have not started before `on_dag_run_failed`")
                 return
 
-            if AIRFLOW_V_2_10_PLUS:
-                task_ids = DagRun._get_partial_task_ids(dag_run.dag)
-            else:
-                task_ids = dag_run.dag.task_ids if dag_run.dag and dag_run.dag.partial else None
+            task_ids = DagRun._get_partial_task_ids(dag_run.dag)
 
             date = dag_run.logical_date
             if AIRFLOW_V_3_0_PLUS and date is None:
