@@ -44,18 +44,17 @@ from airflow.utils.state import DagRunState, State
 from tests_common.test_utils.compat import EmptyOperator, PythonOperator
 from tests_common.test_utils.config import conf_vars
 from tests_common.test_utils.db import clear_db_runs
-from tests_common.test_utils.version_compat import AIRFLOW_V_2_10_PLUS, AIRFLOW_V_3_0_PLUS
+from tests_common.test_utils.version_compat import AIRFLOW_V_3_0_PLUS
 
 pytestmark = pytest.mark.db_test
 
-EXPECTED_TRY_NUMBER_1 = 1 if AIRFLOW_V_2_10_PLUS else 0
-
-TRY_NUMBER_BEFORE_EXECUTION = 0 if AIRFLOW_V_2_10_PLUS else 1
-TRY_NUMBER_RUNNING = 0 if AIRFLOW_V_2_10_PLUS else 1
-TRY_NUMBER_FAILED = 0 if AIRFLOW_V_2_10_PLUS else 1
-TRY_NUMBER_SUCCESS = 0 if AIRFLOW_V_2_10_PLUS else 2
-TRY_NUMBER_AFTER_EXECUTION = 0 if AIRFLOW_V_2_10_PLUS else 2
+EXPECTED_TRY_NUMBER_1 = 1
 
+TRY_NUMBER_BEFORE_EXECUTION = 0
+TRY_NUMBER_RUNNING = 0
+TRY_NUMBER_FAILED = 0
+TRY_NUMBER_SUCCESS = 0
+TRY_NUMBER_AFTER_EXECUTION = 0
 
 if TYPE_CHECKING:
     from airflow.sdk.execution_time.task_runner import RuntimeTaskInstance
@@ -270,6 +269,7 @@ class TestOpenLineageListenerAirflow2:
 
     @mock.patch("airflow.providers.openlineage.conf.debug_mode", return_value=True)
     @mock.patch("airflow.providers.openlineage.plugins.listener.is_operator_disabled")
+    @mock.patch("airflow.providers.openlineage.plugins.listener.get_task_parent_run_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_run_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_mapped_task_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_user_provided_run_facets")
@@ -283,6 +283,7 @@ class TestOpenLineageListenerAirflow2:
         mock_get_airflow_mapped_task_facet,
         mock_get_user_provided_run_facets,
         mock_get_airflow_run_facet,
+        mock_get_task_parent_run_facet,
         mock_disabled,
         mock_debug_mode,
     ):
@@ -299,6 +300,7 @@ class TestOpenLineageListenerAirflow2:
         mock_get_airflow_mapped_task_facet.return_value = {"mapped_facet": 1}
         mock_get_user_provided_run_facets.return_value = {"custom_user_facet": 2}
         mock_get_airflow_run_facet.return_value = {"airflow_run_facet": 3}
+        mock_get_task_parent_run_facet.return_value = {"parent": 4}
         mock_disabled.return_value = False
 
         listener.on_task_instance_running(None, task_instance, None)
@@ -307,14 +309,13 @@ class TestOpenLineageListenerAirflow2:
             job_name="job_name",
             job_description="Test DAG Description",
             event_time="2023-01-01T13:01:01+00:00",
-            parent_job_name="dag_id",
-            parent_run_id="2020-01-01T01:01:01+00:00.dag_id.0",
             code_location=None,
             nominal_start_time=None,
             nominal_end_time=None,
             owners=["Test Owner"],
             task=listener.extractor_manager.extract_metadata(),
             run_facets={
+                "parent": 4,
                 "mapped_facet": 1,
                 "custom_user_facet": 2,
                 "airflow_run_facet": 3,
@@ -324,6 +325,7 @@ class TestOpenLineageListenerAirflow2:
 
     @mock.patch("airflow.providers.openlineage.conf.debug_mode", return_value=True)
     @mock.patch("airflow.providers.openlineage.plugins.listener.is_operator_disabled")
+    @mock.patch("airflow.providers.openlineage.plugins.listener.get_task_parent_run_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_run_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_user_provided_run_facets")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_job_name")
@@ -337,6 +339,7 @@ class TestOpenLineageListenerAirflow2:
         mock_get_job_name,
         mock_get_user_provided_run_facets,
         mock_get_airflow_run_facet,
+        mock_get_task_parent_run_facet,
         mock_disabled,
         mock_debug_mode,
     ):
@@ -353,11 +356,12 @@ class TestOpenLineageListenerAirflow2:
         mock_get_job_name.return_value = "job_name"
         mock_get_user_provided_run_facets.return_value = {"custom_user_facet": 2}
         mock_get_airflow_run_facet.return_value = {"airflow": {"task": "..."}}
+        mock_get_task_parent_run_facet.return_value = {"parent": 4}
         mock_disabled.return_value = False
 
         err = ValueError("test")
-        on_task_failed_listener_kwargs = {"error": err} if AIRFLOW_V_2_10_PLUS else {}
-        expected_err_kwargs = {"error": err if AIRFLOW_V_2_10_PLUS else None}
+        on_task_failed_listener_kwargs = {"error": err}
+        expected_err_kwargs = {"error": err}
 
         listener.on_task_instance_failed(
             previous_state=None, task_instance=task_instance, **on_task_failed_listener_kwargs, session=None
@@ -365,11 +369,10 @@ class TestOpenLineageListenerAirflow2:
         listener.adapter.fail_task.assert_called_once_with(
             end_time="2023-01-03T13:01:01+00:00",
             job_name="job_name",
-            parent_job_name="dag_id",
-            parent_run_id="2020-01-01T01:01:01+00:00.dag_id.0",
             run_id="2020-01-01T01:01:01+00:00.dag_id.task_id.1.-1",
             task=listener.extractor_manager.extract_metadata(),
             run_facets={
+                "parent": 4,
                 "custom_user_facet": 2,
                 "airflow": {"task": "..."},
                 "debug": AirflowDebugRunFacet(packages=ANY),
@@ -379,6 +382,7 @@ class TestOpenLineageListenerAirflow2:
 
     @mock.patch("airflow.providers.openlineage.conf.debug_mode", return_value=True)
     @mock.patch("airflow.providers.openlineage.plugins.listener.is_operator_disabled")
+    @mock.patch("airflow.providers.openlineage.plugins.listener.get_task_parent_run_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_run_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_user_provided_run_facets")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_job_name")
@@ -392,6 +396,7 @@ class TestOpenLineageListenerAirflow2:
         mock_get_job_name,
         mock_get_user_provided_run_facets,
         mock_get_airflow_run_facet,
+        mock_get_task_parent_run_facet,
         mock_disabled,
         mock_debug_mode,
     ):
@@ -408,6 +413,7 @@ class TestOpenLineageListenerAirflow2:
         mock_get_job_name.return_value = "job_name"
         mock_get_user_provided_run_facets.return_value = {"custom_user_facet": 2}
         mock_get_airflow_run_facet.return_value = {"airflow": {"task": "..."}}
+        mock_get_task_parent_run_facet.return_value = {"parent": 4}
         mock_disabled.return_value = False
 
         listener.on_task_instance_success(None, task_instance, None)
@@ -418,11 +424,10 @@ class TestOpenLineageListenerAirflow2:
         assert calls[0][1] == dict(
             end_time="2023-01-03T13:01:01+00:00",
             job_name="job_name",
-            parent_job_name="dag_id",
-            parent_run_id="2020-01-01T01:01:01+00:00.dag_id.0",
             run_id=f"2020-01-01T01:01:01+00:00.dag_id.task_id.{EXPECTED_TRY_NUMBER_1}.-1",
             task=listener.extractor_manager.extract_metadata(),
             run_facets={
+                "parent": 4,
                 "custom_user_facet": 2,
                 "airflow": {"task": "..."},
                 "debug": AirflowDebugRunFacet(packages=ANY),
@@ -460,7 +465,7 @@ class TestOpenLineageListenerAirflow2:
         parameters derived from the task instance.
         """
         listener, task_instance = self._create_listener_and_task_instance()
-        on_task_failed_kwargs = {"error": ValueError("test")} if AIRFLOW_V_2_10_PLUS else {}
+        on_task_failed_kwargs = {"error": ValueError("test")}
 
         listener.on_task_instance_failed(
             previous_state=None, task_instance=task_instance, **on_task_failed_kwargs, session=None
@@ -582,7 +587,7 @@ class TestOpenLineageListenerAirflow2:
         mock_get_user_provided_run_facets.return_value = {"custom_facet": 2}
         mock_disabled.return_value = True
 
-        on_task_failed_kwargs = {"error": ValueError("test")} if AIRFLOW_V_2_10_PLUS else {}
+        on_task_failed_kwargs = {"error": ValueError("test")}
 
         listener.on_task_instance_failed(
             previous_state=None, task_instance=task_instance, **on_task_failed_kwargs, session=None
@@ -683,14 +688,6 @@ class TestOpenLineageListenerAirflow2:
         listener.log.warning.assert_called_once()
 
 
-@pytest.fixture
-def mock_supervisor_comms():
-    with mock.patch(
-        "airflow.sdk.execution_time.task_runner.SUPERVISOR_COMMS", create=True
-    ) as supervisor_comms:
-        yield supervisor_comms
-
-
 @pytest.mark.skipif(not AIRFLOW_V_3_0_PLUS, reason="Airflow 3 tests")
 class TestOpenLineageListenerAirflow3:
     @pytest.mark.skip("Rendering fields is not migrated yet in Airflow 3")
@@ -933,6 +930,7 @@ class TestOpenLineageListenerAirflow3:
 
     @mock.patch("airflow.providers.openlineage.conf.debug_mode", return_value=True)
     @mock.patch("airflow.providers.openlineage.plugins.listener.is_operator_disabled")
+    @mock.patch("airflow.providers.openlineage.plugins.listener.get_task_parent_run_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_run_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_mapped_task_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_user_provided_run_facets")
@@ -946,6 +944,7 @@ class TestOpenLineageListenerAirflow3:
         mock_get_airflow_mapped_task_facet,
         mock_get_user_provided_run_facets,
         mock_get_airflow_run_facet,
+        mock_get_task_parent_run_facet,
         mock_disabled,
         mock_debug_mode,
     ):
@@ -962,6 +961,7 @@ class TestOpenLineageListenerAirflow3:
         mock_get_airflow_mapped_task_facet.return_value = {"mapped_facet": 1}
         mock_get_user_provided_run_facets.return_value = {"custom_user_facet": 2}
         mock_get_airflow_run_facet.return_value = {"airflow_run_facet": 3}
+        mock_get_task_parent_run_facet.return_value = {"parent": 4}
         mock_disabled.return_value = False
 
         listener.on_task_instance_running(None, task_instance)
@@ -970,8 +970,6 @@ class TestOpenLineageListenerAirflow3:
             job_name="job_name",
             job_description="Test DAG Description",
             event_time="2023-01-01T13:01:01+00:00",
-            parent_job_name="dag_id",
-            parent_run_id="2020-01-01T01:01:01+00:00.dag_id.0",
             code_location=None,
             nominal_start_time=None,
             nominal_end_time=None,
@@ -981,12 +979,14 @@ class TestOpenLineageListenerAirflow3:
                 "mapped_facet": 1,
                 "custom_user_facet": 2,
                 "airflow_run_facet": 3,
+                "parent": 4,
                 "debug": AirflowDebugRunFacet(packages=ANY),
             },
         )
 
     @mock.patch("airflow.providers.openlineage.conf.debug_mode", return_value=True)
     @mock.patch("airflow.providers.openlineage.plugins.listener.is_operator_disabled")
+    @mock.patch("airflow.providers.openlineage.plugins.listener.get_task_parent_run_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_run_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_user_provided_run_facets")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_job_name")
@@ -1000,6 +1000,7 @@ class TestOpenLineageListenerAirflow3:
         mock_get_job_name,
         mock_get_user_provided_run_facets,
         mock_get_airflow_run_facet,
+        mock_get_task_parent_run_facet,
         mock_disabled,
         mock_debug_mode,
     ):
@@ -1016,11 +1017,12 @@ class TestOpenLineageListenerAirflow3:
         mock_get_job_name.return_value = "job_name"
         mock_get_user_provided_run_facets.return_value = {"custom_user_facet": 2}
         mock_get_airflow_run_facet.return_value = {"airflow": {"task": "..."}}
+        mock_get_task_parent_run_facet.return_value = {"parent": 4}
         mock_disabled.return_value = False
 
         err = ValueError("test")
-        on_task_failed_listener_kwargs = {"error": err} if AIRFLOW_V_2_10_PLUS else {}
-        expected_err_kwargs = {"error": err if AIRFLOW_V_2_10_PLUS else None}
+        on_task_failed_listener_kwargs = {"error": err}
+        expected_err_kwargs = {"error": err}
 
         listener.on_task_instance_failed(
             previous_state=None, task_instance=task_instance, **on_task_failed_listener_kwargs
@@ -1028,11 +1030,10 @@ class TestOpenLineageListenerAirflow3:
         listener.adapter.fail_task.assert_called_once_with(
             end_time="2023-01-03T13:01:01+00:00",
             job_name="job_name",
-            parent_job_name="dag_id",
-            parent_run_id="2020-01-01T01:01:01+00:00.dag_id.0",
             run_id="2020-01-01T01:01:01+00:00.dag_id.task_id.1.-1",
             task=listener.extractor_manager.extract_metadata(),
             run_facets={
+                "parent": 4,
                 "custom_user_facet": 2,
                 "airflow": {"task": "..."},
                 "debug": AirflowDebugRunFacet(packages=ANY),
@@ -1041,6 +1042,7 @@ class TestOpenLineageListenerAirflow3:
         )
 
     @mock.patch("airflow.providers.openlineage.conf.debug_mode", return_value=True)
+    @mock.patch("airflow.providers.openlineage.plugins.listener.get_task_parent_run_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_job_name")
     @mock.patch(
         "airflow.providers.openlineage.plugins.listener.OpenLineageListener._execute", new=regular_call
@@ -1050,6 +1052,7 @@ class TestOpenLineageListenerAirflow3:
         self,
         mock_utcnow,
         mock_get_job_name,
+        mock_get_task_parent_run_facet,
         mock_debug_mode,
     ):
         """Tests that the 'fail_task' method of the OpenLineageAdapter is invoked with the correct arguments.
@@ -1060,27 +1063,33 @@ class TestOpenLineageListenerAirflow3:
 
         listener, task_instance = self._create_listener_and_task_instance(runtime_ti=False)
         mock_get_job_name.return_value = "job_name"
+        mock_get_task_parent_run_facet.return_value = {"parent": 4}
 
         err = ValueError("test")
-        on_task_failed_listener_kwargs = {"error": err} if AIRFLOW_V_2_10_PLUS else {}
-        expected_err_kwargs = {"error": err if AIRFLOW_V_2_10_PLUS else None}
+        on_task_failed_listener_kwargs = {"error": err}
+        expected_err_kwargs = {"error": err}
 
         listener.on_task_instance_failed(
             previous_state=None, task_instance=task_instance, **on_task_failed_listener_kwargs
         )
+        mock_get_task_parent_run_facet.assert_called_once_with(
+            parent_run_id="2020-01-01T01:01:01+00:00.dag_id.0", parent_job_name=task_instance.dag_id
+        )
         listener.adapter.fail_task.assert_called_once_with(
             end_time="2023-01-03T13:01:01+00:00",
             job_name="job_name",
-            parent_job_name="dag_id",
-            parent_run_id="2020-01-01T01:01:01+00:00.dag_id.0",
             run_id="2020-01-01T01:01:01+00:00.dag_id.task_id.1.-1",
             task=OperatorLineage(),
-            run_facets={"debug": AirflowDebugRunFacet(packages=ANY)},
+            run_facets={
+                "parent": 4,
+                "debug": AirflowDebugRunFacet(packages=ANY),
+            },
             **expected_err_kwargs,
         )
 
     @mock.patch("airflow.providers.openlineage.conf.debug_mode", return_value=True)
     @mock.patch("airflow.providers.openlineage.plugins.listener.is_operator_disabled")
+    @mock.patch("airflow.providers.openlineage.plugins.listener.get_task_parent_run_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_run_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_user_provided_run_facets")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_job_name")
@@ -1094,6 +1103,7 @@ class TestOpenLineageListenerAirflow3:
         mock_get_job_name,
         mock_get_user_provided_run_facets,
         mock_get_airflow_run_facet,
+        mock_get_task_parent_run_facet,
         mock_disabled,
         mock_debug_mode,
     ):
@@ -1110,6 +1120,7 @@ class TestOpenLineageListenerAirflow3:
         mock_get_job_name.return_value = "job_name"
         mock_get_user_provided_run_facets.return_value = {"custom_user_facet": 2}
         mock_get_airflow_run_facet.return_value = {"airflow": {"task": "..."}}
+        mock_get_task_parent_run_facet.return_value = {"parent": 4}
         mock_disabled.return_value = False
 
         listener.on_task_instance_success(None, task_instance)
@@ -1118,11 +1129,10 @@ class TestOpenLineageListenerAirflow3:
         assert calls[0][1] == dict(
             end_time="2023-01-03T13:01:01+00:00",
             job_name="job_name",
-            parent_job_name="dag_id",
-            parent_run_id="2020-01-01T01:01:01+00:00.dag_id.0",
             run_id="2020-01-01T01:01:01+00:00.dag_id.task_id.1.-1",
             task=listener.extractor_manager.extract_metadata(),
             run_facets={
+                "parent": 4,
                 "custom_user_facet": 2,
                 "airflow": {"task": "..."},
                 "debug": AirflowDebugRunFacet(packages=ANY),
@@ -1130,6 +1140,7 @@ class TestOpenLineageListenerAirflow3:
         )
 
     @mock.patch("airflow.providers.openlineage.conf.debug_mode", return_value=True)
+    @mock.patch("airflow.providers.openlineage.plugins.listener.get_task_parent_run_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_job_name")
     @mock.patch(
         "airflow.providers.openlineage.plugins.listener.OpenLineageListener._execute", new=regular_call
@@ -1139,6 +1150,7 @@ class TestOpenLineageListenerAirflow3:
         self,
         mock_utcnow,
         mock_get_job_name,
+        mock_get_task_parent_run_facet,
         mock_debug_mode,
     ):
         """Tests that the 'complete_task' method of the OpenLineageAdapter is called with the correct arguments.
@@ -1148,18 +1160,23 @@ class TestOpenLineageListenerAirflow3:
         """
         listener, task_instance = self._create_listener_and_task_instance(runtime_ti=False)
         mock_get_job_name.return_value = "job_name"
+        mock_get_task_parent_run_facet.return_value = {"parent": 4}
 
         listener.on_task_instance_success(None, task_instance)
         calls = listener.adapter.complete_task.call_args_list
         assert len(calls) == 1
+        mock_get_task_parent_run_facet.assert_called_once_with(
+            parent_run_id="2020-01-01T01:01:01+00:00.dag_id.0", parent_job_name=task_instance.dag_id
+        )
         assert calls[0][1] == dict(
             end_time="2023-01-03T13:01:01+00:00",
             job_name="job_name",
-            parent_job_name="dag_id",
-            parent_run_id="2020-01-01T01:01:01+00:00.dag_id.0",
             run_id="2020-01-01T01:01:01+00:00.dag_id.task_id.1.-1",
             task=OperatorLineage(),
-            run_facets={"debug": AirflowDebugRunFacet(packages=ANY)},
+            run_facets={
+                "parent": 4,
+                "debug": AirflowDebugRunFacet(packages=ANY),
+            },
         )
 
     @mock.patch(
@@ -1193,7 +1210,7 @@ class TestOpenLineageListenerAirflow3:
         parameters derived from the task instance.
         """
         listener, task_instance = self._create_listener_and_task_instance()
-        on_task_failed_kwargs = {"error": ValueError("test")} if AIRFLOW_V_2_10_PLUS else {}
+        on_task_failed_kwargs = {"error": ValueError("test")}
 
         listener.on_task_instance_failed(
             previous_state=None, task_instance=task_instance, **on_task_failed_kwargs
@@ -1256,7 +1273,7 @@ class TestOpenLineageListenerAirflow3:
         mock_get_user_provided_run_facets.return_value = {"custom_facet": 2}
         mock_disabled.return_value = True
 
-        on_task_failed_kwargs = {"error": ValueError("test")} if AIRFLOW_V_2_10_PLUS else {}
+        on_task_failed_kwargs = {"error": ValueError("test")}
 
         listener.on_task_instance_failed(
             previous_state=None, task_instance=task_instance, **on_task_failed_kwargs
@@ -1435,7 +1452,7 @@ class TestOpenLineageSelectiveEnableAirflow2:
         if enable_task:
             enable_lineage(self.task_1)
 
-        on_task_failed_kwargs = {"error": ValueError("test")} if AIRFLOW_V_2_10_PLUS else {}
+        on_task_failed_kwargs = {"error": ValueError("test")}
 
         with conf_vars({("openlineage", "selective_enable"): selective_enable}):
             listener = OpenLineageListener()
@@ -1493,7 +1510,7 @@ class TestOpenLineageSelectiveEnableAirflow2:
         if enable_task:
             enable_lineage(self.task_1)
 
-        on_task_failed_kwargs = {"error": ValueError("test")} if AIRFLOW_V_2_10_PLUS else {}
+        on_task_failed_kwargs = {"error": ValueError("test")}
 
         with conf_vars({("openlineage", "selective_enable"): selective_enable}):
             listener = OpenLineageListener()
